function [classes, cert] = nneigh_class(x, xlearn, labels)
//-----------------------------------------------------------------------  
// function [classes, cert] = nneigh_class(x, xlearn, labels)
//
// implementation of nearest neighbour classification 
// of two-dimensional vectors based on learning set. 
//
// input:    x            n1 times n2 - matrix consisting of n points to be 
//                        classified
//           xlearn       n1 times m - matrix consisting of learning 
//                        points
//           labels       m-vector of integer class-labels.             
//
// output:   classes      n2-vector of estimated class memberships, integers 
//           cert         n2-vector of "certainty" measures for the 
//                        classifications, in this case e^(-dmin^2)
//                        (only heuristic, no theoretic foundation for
//                        "certainty")
//
//-----------------------------------------------------------------------  
//   $RCSfile: nneigh_class.sci,v $
//  $Revision: 1.1 $
//      $Date: 2002/09/10 15:15:36 $
//  Copyright: IIF-LMB $Author: poluru $
//
//-----------------------------------------------------------------------
//  $Log: nneigh_class.sci,v $
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//-----------------------------------------------------------------------

  [out,in] = argn(0);

  if in~=3,     
    if in~=1  
      error('wrong number of input arguments.');
    end; 
    
    //setting default classification data if it's not given by the
    //user. works only for 2-dimensional classification. 
    //"DATA" is the absolute path to the "data" directory. 
    global DATA;
    exec(DATA+'data.sci');
    xlearn=V;
    labels=l;    
  end;
  
  n1 = size(x,1);
  n2 = size(x,2);
  m = size(xlearn,2);
  
  if n1~=size(xlearn,1),
    error('Dimensions of xlearn & data(x) should be equal');
  end;
  
  if m~=size(labels,2),
    if m~=size(labels,1),
      error('Length of xlearn & labels should be equal');
    end;
    labels=labels';
  end;
     
  // generate ntest x nlearn coordinate matrices by 'repetition' 
  testx  = list(); 
  learnx = list();
  distsqr= 0;
  
  for i=1:n1,
    testx(i) = x(i,:)' * ones(1,m);   
    learnx(i) = (xlearn(i,:)' * ones(1,n2))';   
    
    // generate squared-distance matrix for all learn/test-pairs
    distsqr = distsqr + (testx(i)-learnx(i)).^2 
  end
 
  
  // find minima and indices
  [distsqrmin, indmin] = min(distsqr,'c');
  classes = labels(indmin);
  cert = exp(-distsqrmin)';
  
endfunction










